@@ -485,6 +485,10 @@ class Client:
     def base_url(self):
         return self._connection["base_url"]
 
+    def locations(self):
+        loc = Locations(None, self._session, self._connection)
+        return loc.get(None, verbose=True)
+
     def put_sensor(self, payload, dry=False):
         sensor = Sensors(payload, self._session, self._connection)
         sensor.put(dry)
@@ -586,10 +590,23 @@ class Client:
             None, entity=entity, **kw
         )
 
+    def get_observation(self, ptime, result, **kw):
+        query = f"phenomenonTime eq {ptime} and result eq {result}"
+        gen = Observations(None, self._session, self._connection).get(
+            query, entity="Observations", **kw
+        )
+        try:
+            return next(gen)
+        except StopIteration:
+            return
+
 
 if __name__ == "__main__":
-    payload = {}
-    l = Locations(payload, None, None)
-    l._validate_payload()
+    # payload = {}
+    # l = Locations(payload, None, None)
+    # l._validate_payload()
+    # obs = Observations({}, None, None)
+    c = Client()
+    print(c.get_observation("2022-07-17T13:12:29.000Z", 12.5044))
 
 # ============= EOF =============================================
